@@ -146,6 +146,12 @@ class AllureHelper(object):
 
         return self.label(Label.STORY, *stories)
 
+    def issue(self, *issues):
+        """
+        A decorator factory that returns ``pytest.mark`` for a given issues.
+        """
+        return self.label(Label.ISSUE, *issues)
+
     def step(self, title):
         """
         A contextmanager/decorator for steps.
